# source https://github.com/TigerVNC/tigervnc/archive/v1.8.0.tar.gz
%global _disable_ld_no_undefined 1

Name:           tigervnc
Version:        1.8.0
Release:        %mkrel 1
Summary:	Viewer for the VNC remote display system

Group:		Networking/Remote access
License:        GPLv2+
URL:            http://www.tigervnc.com/
Source0:        %{name}-%{version}.tar.xz
Source1:	10-libvnc.conf
Patch3:		tigervnc-1.8.0-libvnc-os.patch
Patch7:         tigervnc-manpages.patch
Patch8:         tigervnc-getmaster.patch
Patch9:         tigervnc-shebang.patch
Patch10:        tigervnc11-mdv-link.patch
Patch12:        tigervnc11-mdv-buildir.patch
Patch14:        tigervnc-xstartup.patch
Patch29:	tigervnc-1.7.0-CVE-2014-8241.patch
Patch30:	tigervnc-1.8.0-CVE-2014-8240.patch
Patch100:       tigervnc-xserver119.patch

BuildRequires:	cmake
BuildRequires:	java-1.8.0-sun-devel
BuildRequires:	%{_lib}drm-devel
BuildRequires:	%{_lib}fltk-devel
BuildRequires:	%{_lib}gnutls-devel
BuildRequires:  %{_lib}openssl-devel
BuildRequires:	%{_lib}pam-devel
BuildRequires:	%{_lib}pixman-devel
BuildRequires:	%{_lib}unwind-devel
BuildRequires:	%{_lib}xau-devel
BuildRequires:	%{_lib}xdamage-devel
BuildRequires:	%{_lib}xdmcp-devel
BuildRequires:	%{_lib}xfont1-devel
BuildRequires:  %{_lib}xfont2-devel
BuildRequires:	%{_lib}xkbfile-devel
BuildRequires:	%{_lib}xshmfence-devel
BuildRequires:	%{_lib}xtst-devel
BuildRequires:	libpthread-stubs
BuildRequires:  x11-server-source
BuildRequires:	x11-util-macros
BuildRequires:  x11-xtrans-devel
BuildRequires:	x11-font-util
BuildRequires:  xmlto

%description
Virtual Network Computing (VNC) is a remote display system which
allows you to view a computing 'desktop' environment not only on the
machine where it is running, but from anywhere on the Internet and
from a wide variety of machine architectures.  This package contains a
client which will allow you to connect to other desktops running a VNC
server.

%files -f %{name}.lang
%doc %{_defaultdocdir}/%{name}-%{version}/*
%{_bindir}/vncviewer
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_desktopdir}/vncviewer.desktop
%{_mandir}/man1/vncviewer.1*

%package  server
Summary:  Server for the VNC remote display system
Group:    Networking/Remote access
Provides: vnc-server
Requires: vnc-server-common

%description server
The VNC system allows you to access the same desktop from a wide
variety of platforms.  This package is a TigerVNC server, allowing
others to access the desktop on your machine.

%files server
%{_bindir}/vncconfig
%{_bindir}/vncpasswd
%{_bindir}/x0vncserver
%{_bindir}/Xvnc
%{_bindir}/vncserver
%{_mandir}/man1/Xvnc.1*
%{_mandir}/man1/vncpasswd.1*
%{_mandir}/man1/vncconfig.1*
%{_mandir}/man1/vncserver.1*
%{_mandir}/man1/x0vncserver.1*

%package   server-module
Summary:   Xorg module for the VNC remote display system
Group:     Networking/Remote access
Requires:  x11-server-xorg

%description server-module
This package contains libvnc.so module to X server, allowing others
to access the desktop on your machine.

%files server-module
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/10-libvnc.conf
%{_libdir}/xorg/modules/extensions/libvnc.so

%package  java
Summary:  Java viewer for the VNC remote display system
Group:    Networking/Remote access
Requires: jre

%description java
This distribution is based on the standard VNC source and includes new
TightVNC-specific features and fixes, such as additional low-bandwidth
optimizations, major GUI improvements, and more.

There are three basic ways to use TigerVNC Java viewer:
  1. Running applet as part of TigerVNC server installation.
  2. Running applet hosted on a standalone Web server.
  3. Running the viewer as a standalone application.

%files java
%doc java/com/tigervnc/vncviewer/README
%{_javadir}/*.jar
%{_datadir}/vnc

%prep
%setup -q
%patch3 -p1 -b .libvnc-os
%patch7 -p1 -b .manpages
%patch8 -p1 -b .getmaster
%patch9 -p1 -b .shebang
%patch10 -p1 -b .link
%patch12 -p1 -b .builddir
%patch14 -p1 -b .xstartup
%patch29 -p1 -b .CVE-2014-8241
%patch30 -p1 -b .CVE-2014-8240

cp -r /usr/share/x11-server-source/* unix/xserver
pushd unix/xserver
for all in `find . -type f -perm -001`; do
  chmod -x "$all"
done
%patch100 -p1 -b .xserver116-rebased
popd

%build
%cmake
%make_build
cd ..

pushd unix/xserver
rm -f configure
%serverbuild
autoreconf -fiv
%configure2_5x \
  --disable-xorg --disable-xnest --disable-xvfb --disable-dmx \
  --disable-xwin --disable-xephyr --disable-kdrive --disable-xwayland \
  --with-pic --disable-static --disable-xinerama \
  --with-default-font-path="catalogue:%{_sysconfdir}/X11/fontpath.d,built-ins" \
  --with-fontrootdir=%{_datadir}/X11/fonts --with-xkb-output=%{_localstatedir}/lib/xkb \
  --enable-glx --disable-dri --enable-dri2 --enable-dri3  \
  --disable-present --disable-config-hal --disable-config-udev --without-dtrace \
  --disable-unit-tests --disable-devel-docs --disable-selective-werror
%make_build
popd

# Build icons
pushd media
%cmake
%make_build
popd

# Build Java applet
pushd java
%cmake
JAVA_TOOL_OPTIONS="-Dfile.encoding=UTF8" \
%make_build
popd

%install
%make_install -C build
%make_install -C unix/xserver/hw/vnc

# Install desktop stuff
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{16x16,24x24,48x48}/apps
pushd media/icons
for s in 16 24 48; do
install -m644 tigervnc_$s.png %{buildroot}%{_datadir}/icons/hicolor/${s}x$s/apps/tigervnc.png
done
popd

%__install -Dm 644 %{S:1} %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/10-libvnc.conf
%find_lang %{name} %{name}.lang

# remove unwanted files
rm -f  %{buildroot}%{_libdir}/xorg/modules/extensions/libvnc.la

# Install Java applet
install -d -m 755 %{buildroot}%{_javadir}
install -d -m 755 %{buildroot}%{_datadir}/vnc/classes
pushd java/build
install -m 755 VncViewer.jar %{buildroot}%{_datadir}/vnc/classes/vncviewer-%{version}.jar
popd

pushd java
install -m 644 com/tigervnc/vncviewer/index.vnc %{buildroot}%{_datadir}/vnc/classes
popd

pushd %{buildroot}%{_datadir}/vnc/classes
mv vncviewer-%{version}.jar %{buildroot}%{_javadir}
ln -s %{_javadir}/vncviewer-%{version}.jar VncViewer.jar
popd

pushd %{buildroot}%{_javadir}
ln -s vncviewer-%{version}.jar vncviewer.jar
ln -s vncviewer-%{version}.jar VncViewer.jar
popd

%changelog
* Mon Oct 16 2017 marcin82 <marcin82 at vp.pl> 1.8.0-1pclos2017
- update, rewrote patch 3,30, removed patch 1,2
- updated BR, applied %%serverbuild flags

* Fri Mar 17 2017 bb <bb> 1.7.0-1pclos2017
- update

* Sun Jan 01 2017 bb2 <bb2> - 1.6.0-2pclos2017
- rebuild new gnutls
